==> anwiba-commons-json-1.0.64-sources.jar: net/anwiba/commons/json/schema/v1_0/StringProperty.java <==
//Copyright (c) 2016 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonProperty;

public class StringProperty
    extends Property
{

    private final String type = "string";
    private String _default = null;
    private String format = null;
    private Integer minLength = null;
    private Integer maxLength = null;
    private String minimum = null;
    private String maximum = null;
    private String exclusiveMinimum = null;
    private String exclusiveMaximum = null;
    private String[] _enum = null;
    private String contentEncoding = null;
    private String mediaType = null;

    @JsonProperty("type")
    public void setType(final String type) {
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final String _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public String getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("minLength")
    public void setMinLength(final Integer minLength) {
        this.minLength = minLength;
    }

    @JsonProperty("minLength")
    public Integer getMinLength() {
        return this.minLength;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final String minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public String getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final String maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public String getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final String exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public String getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final String exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public String getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("enum")
    public void setEnum(final String[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public String[] getEnum() {
        return this._enum;
    }

    @JsonProperty("contentEncoding")
    public void setContentEncoding(final String contentEncoding) {
        this.contentEncoding = contentEncoding;
    }

    @JsonProperty("contentEncoding")
    public String getContentEncoding() {
        return this.contentEncoding;
    }

    @JsonProperty("mediaType")
    public void setMediaType(final String mediaType) {
        this.mediaType = mediaType;
    }

    @JsonProperty("mediaType")
    public String getMediaType() {
        return this.mediaType;
    }

}

==> anwiba-commons-json-1.0.140-sources.jar: net/anwiba/commons/json/schema/v1_0/StringProperty.java <==
//Copyright (c) 2016 by Andreas W. Bartels
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class StringProperty
    extends Property
{

    private final String type = "string";
    private String _default = null;
    private String format = null;
    private Integer minLength = null;
    private Integer maxLength = null;
    private String minimum = null;
    private String maximum = null;
    private String exclusiveMinimum = null;
    private String exclusiveMaximum = null;
    private String[] _enum = null;
    private String contentEncoding = null;
    private String mediaType = null;

    @JsonIgnore
    public void setType(final String type) {
    }

    @JsonIgnore
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final String _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public String getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("minLength")
    public void setMinLength(final Integer minLength) {
        this.minLength = minLength;
    }

    @JsonProperty("minLength")
    public Integer getMinLength() {
        return this.minLength;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final String minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public String getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final String maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public String getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final String exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public String getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final String exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public String getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("enum")
    public void setEnum(final String[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public String[] getEnum() {
        return this._enum;
    }

    @JsonProperty("contentEncoding")
    public void setContentEncoding(final String contentEncoding) {
        this.contentEncoding = contentEncoding;
    }

    @JsonProperty("contentEncoding")
    public String getContentEncoding() {
        return this.contentEncoding;
    }

    @JsonProperty("mediaType")
    public void setMediaType(final String mediaType) {
        this.mediaType = mediaType;
    }

    @JsonProperty("mediaType")
    public String getMediaType() {
        return this.mediaType;
    }

}
